[![icpp-pro](https://github.com/icppWorld/icpp-pro/actions/workflows/cicd.yml/badge.svg)](https://github.com/icppWorld/icpp-pro/actions/workflows/cicd.yml)

# C++ Canister Development Kit

icpp-pro is a cdk to develop C++ smart contracts for the  [Internet Computer](https://internetcomputer.org/):

## Installation

```bash
pip install icpp-pro
```

## Support

For support, kindly create a GitHub Issue as outlined in the [Support](https://docs.icpp.world/support.html) documentation page.
  

## Documentation

The docs can be found [here](https://docs.icpp.world)

